@@ -301,7 +301,7 @@ class TgWrap():
             stop_processing = True
         finally:
             if error_msg:
-                output = f'{"exception": "{error_msg}"}'
+                output = f'{{"exception": "{error_msg}"}}'
 
             try:
                 # communicate the results if desired
